// AUTO-GENERATED BY UpdateGenVersion.bat 440ba076e4cdac3d7c2c29691141904ea904a5ef
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "440ba076e4cdac3d7c2c29691141904ea904a5ef";
